@@ -10,21 +10,21 @@ use Net::DRI;
 
 my ($rc,$dri);
 
-my $ok=eval {
+eval {
 
-$dri=Net::DRI->new({cache_ttl => 10});
+$dri=Net::DRI->new(10);
 $dri->add_registry('EURid',{});
 $rc=$dri->target('EURid')->add_current_profile('profile1','das');
 die($rc) unless $rc->is_success();
 das('europa.eu');
 das('netdri-test-doestnotexist.eu');
-$dri->add_registry('DNSBelgium',{});
-$rc=$dri->target('DNSBelgium')->add_current_profile('profile1','das');
+$dri->add_registry('BE',{});
+$rc=$dri->target('BE')->add_current_profile('profile1','das');
 die($rc) unless $rc->is_success();
 das('brussels.be');
 das('netdri-test-doestnotexist.be');
-$dri->add_registry('auDA',{});
-$rc=$dri->target('auDA')->add_current_profile('profile1','das');
+$dri->add_registry('AU',{});
+$rc=$dri->target('AU')->add_current_profile('profile1','das');
 die($rc) unless $rc->is_success();
 das('domain.com.au');
 das('netdri-test-doestnotexist.com.au');
@@ -49,16 +49,15 @@ das('netdri-test-doestnotexist.com');
 $dri->end();
 };
 
-if (! $ok)
+if ($@)
 { 
- my $err=$@;
  print "\n\nAn EXCEPTION happened !\n";
- if (ref $err)
+ if (ref($@))
  {
-  $err->print();
+  $@->print();
  } else
  {
-  print $err;
+  print($@);
  }
 } else
 {
