@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Handling of contact data for EURid
 ##
-## Copyright (c) 2005,2006,2007,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2006,2007,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -18,14 +18,17 @@
 package Net::DRI::Data::Contact::EURid;
 
 use strict;
+use warnings;
+
 use base qw/Net::DRI::Data::Contact/;
-__PACKAGE__->mk_accessors(qw(type vat lang onhold monitoring_status));
 
 use Net::DRI::DRD::EURid;
 use Net::DRI::Exception;
 use Net::DRI::Util;
 
-our $VERSION=do { my @r=(q$Revision: 1.8 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.10 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
+__PACKAGE__->register_attributes(qw(type vat lang onhold monitoring_status));
 
 =pod
 
@@ -80,7 +83,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006,2007,2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2006,2007,2008,2009 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -131,12 +134,12 @@ sub validate
 
 sub init
 {
- my ($self,$what)=@_;
-
+ my ($self,$what,$ndr)=@_;
  if ($what eq 'create')
  {
   my $a=$self->auth();
   $self->auth({pw=>''}) unless ($a && (ref($a) eq 'HASH') && exists($a->{pw}));
+  $self->srid('ABCD') unless defined $self->srid(); ## we can not choose the ID
  }
 }
 
