@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Encapsulating raw data
 ##
-## Copyright (c) 2005,2006,2007,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -18,10 +18,15 @@
 package Net::DRI::Data::Raw;
 
 use strict;
+use warnings;
 
+use Data::Dumper ();
 use Net::DRI::Exception;
 
-our $VERSION=do { my @r=(q$Revision: 1.9 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+use base qw(Class::Accessor::Fast);
+__PACKAGE__->mk_ro_accessors(qw(type data hint));
+
+our $VERSION=do { my @r=(q$Revision: 1.11 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -51,7 +56,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006,2007,2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2010 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,22 +68,23 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
-
 ####################################################################################################
 
 sub new
 {
  my $class=shift;
- my ($type,$data)=@_;
+ my ($type,$data,$hint)=@_;
 
 ## type=1, data=ref to array
 ## type=2, data=string
 ## type=3, data=ref to string NOTIMPL
 ## type=4, data=path to local file NOTIMPL
 ## type=5, data=object with a as_string method
+## type=6, data=complex object in a ref array
 
  my $self={type => $type,
            data => $data,
+           hint => $hint || '',
           };
 
  bless($self,$class);
@@ -93,13 +99,9 @@ sub new_from_array
  return $class->new(1,\@a);
 }
 
-sub new_from_string { return shift->new(2,shift); }
-sub new_from_object { return shift->new(5,shift); }
-
-####################################################################################################
-
-sub type { return shift->{type}; }
-sub data { return shift->{data}; }
+sub new_from_string    { return shift->new(2,@_); }
+sub new_from_xmlstring { return shift->new(2,$_[0],'xml'); }
+sub new_from_object    { return shift->new(5,@_); }
 
 ####################################################################################################
 
@@ -122,6 +124,10 @@ sub as_string
   Net::DRI::Exception::err_method_not_implemented('as_string in '.ref($data)) unless $data->can('as_string');
   return $data->as_string();
  }
+ if ($self->type()==6)
+ {
+  return Data::Dumper->new($data)->Indent(2)->Varname('')->Quotekeys(0)->Sortkeys(1)->Dump();
+ }
 }
 
 sub last_line
