@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Encapsulatng errors (fatal or not) as exceptions in an OO way
 ##
-## Copyright (c) 2005,2007,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2007,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -21,7 +21,7 @@ use strict;
 
 use Carp;
 
-our $VERSION=do { my @r=(q$Revision: 1.7 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.8 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -65,8 +65,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2007,2008 Patrick Mevzek <netdri@dotandco.com>.
-All rights reserved.
+Copyright (c) 2005,2007,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -108,7 +107,8 @@ sub backtrace
  my $self=shift;
  my $m=$self->{bt};
  my (@bt1,@bt2);
- foreach (split(/\n/,$m)) { if (/^\s*Net::DRI::Exception::/) { push @bt1,$_; } else { push @bt2,$_; } }
+ foreach (split(/\n/,$m)) { if (/^\s*Net::DRI::(?:BaseClass|Exception)::/) { push @bt1,$_; } else { push @bt2,$_; } }
+ shift(@bt2) if ($bt2[0]=~m!Net/DRI/BaseClass!);
  shift(@bt2) if ($bt2[0]=~m!Net/DRI/Exception!);
  my ($f,$l);
  if (@bt1)
@@ -124,7 +124,7 @@ sub backtrace
  return (@b,@bt2);
 }
 
-## Do not parse result of this call. If needed use accessors above (is_error(), area(), code(), msg())
+## Do not parse result of this call. If needed, use accessors above (is_error(), area(), code(), msg())
 sub as_string
 {
  my $self=shift;
