@@ -1,6 +1,6 @@
-## Domain Registry Interface, SYSLOG Logging operations for Net::DRI
+## Domain Registry Interface, SYSLOG Logging operations for Net::DRI 
 ##
-## Copyright (c) 2009,2013,2014 Jørgen Thomsen <netdri@jth.net>. All rights reserved
+## Copyright (c) 2009 Jrgen Thomsen <netdri@jth.net>. All rights reserved. 
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,11 +10,13 @@
 ## (at your option) any later version. 
 ##
 ## See the LICENSE file that comes with this distribution for more details. 
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Logging::Syslog;
 
-use utf8;
 use strict;
 use warnings;
 
@@ -22,6 +24,8 @@ use base qw/Net::DRI::Logging/;
 
 use Sys::Syslog qw(:DEFAULT);
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/gxm); sprintf '%d'.('.%02d' x $#r), @r; };
+
 ####################################################################################################
 
 sub new
@@ -55,7 +59,7 @@ sub output
  if ($self->should_log($level)) {
 	my @lines = split( /\n/, $self->tostring($level,$type,$data) ); # log each indented line when xml_indent => 1
 	foreach (@lines) {
-               syslog($self->{priority}, ($self->{logopened} != 2 ? $self->{ident}.': ':'')."%s", $_);
+		syslog($self->{priority}.'|'.$self->{facility}, ($self->{logopened} != 2 ? $self->{ident}.': ':'')."%s", $_);
 	}
  }
  return;
@@ -74,12 +78,16 @@ __END__
 
 =pod
 
-=encoding utf8
-
 =head1 NAME
 
 Net::DRI::Logging::Syslog - SYSLOG Logging Operations for Net::DRI
 
+=head1 VERSION
+
+This documentation refers to Net::DRI::Logging::Syslog version 1.01
+
+Read e.g. with pod2text Net/DRI/Logging/Syslog.pm|less
+
 =head1 SYNOPSIS
 
 See L<Net::DRI::Logging>
@@ -174,11 +182,11 @@ E<lt>http://www.dotandco.com/services/software/Net-DRI/E<gt>
 
 =head1 AUTHOR
 
-Jørgen Thomsen, E<lt>netdri@jth.netE<gt>
+Jrgen Thomsen, E<lt>netdri@jth.netE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009,2013,2014 Jørgen Thomsen <netdri@jth.net>. All rights reserved.
+Copyright (c) 2009 Jrgen Thomsen <netdri@jth.net>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the Free
