@@ -1,6 +1,6 @@
 ## Domain Registry Interface, AdamsNames Web Services Domain commands
 ##
-## Copyright (c) 2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,6 +10,9 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::AdamsNames::WS::Domain;
@@ -20,6 +23,8 @@ use warnings;
 use Net::DRI::Exception;
 use Net::DRI::Util;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -48,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2009 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -79,7 +84,6 @@ sub build_msg
  Net::DRI::Exception->die(1,'protocol/adamsnames/ws',10,'Invalid domain name') unless Net::DRI::Util::is_hostname($domain);
 
  $msg->method($command) if defined($command);
- return;
 }
 
 sub info
@@ -88,7 +92,6 @@ sub info
  my $msg=$po->message();
  build_msg($msg,'domquery',$domain);
  $msg->params([$domain]);
- return;
 }
 
 sub info_parse
@@ -125,7 +128,6 @@ sub info_parse
 
  $rinfo->{domain}->{$oname}->{ns}=$h;
  $rinfo->{domain}->{$oname}->{roid}=$r{id};
- return;
 }
 
 ####################################################################################################
