@@ -1,6 +1,6 @@
 ## Domain Registry Interface, CIRA EPP Domain extensions
 ##
-## Copyright (c) 2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,6 +10,9 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::CIRA::Domain;
@@ -20,6 +23,8 @@ use warnings;
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 ####################################################################################################
 
 sub register_commands
@@ -36,6 +41,12 @@ sub register_commands
 
 ####################################################################################################
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+ return $mes->command_extension_register($tag,sprintf('xmlns:cira="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('cira')));
+}
+
 sub info_parse
 {
  my ($po,$otype,$oaction,$oname,$rinfo)=@_;
@@ -56,7 +67,6 @@ sub info_parse
    $rinfo->{domain}->{$oname}->{stage_of_life_end}=$po->parse_iso8601($c->textContent());
   }
  }
- return;
 }
 
 sub create
@@ -71,13 +81,12 @@ sub create
  @c=$cs->get('tech');
  return unless @c;
  Net::DRI::Exception::usererr_insufficient_parameters('only up to 3 tech contacts are possible in .CA for domain_create') if (scalar(@c)!=scalar(grep { Net::DRI::Util::isa_contact($_,'Net::DRI::Data::Contact::CIRA') && length $_->srid() && $_->validate(1) } @c) || @c>3);
- return;
 }
 
 sub transfer_request
 {
  my ($epp,$domain,$rd)=@_;
-
+ my $mes=$epp->message();
  return unless Net::DRI::Util::has_contact($rd);
 
  my @n;
@@ -85,21 +94,19 @@ sub transfer_request
  Net::DRI::Exception::usererr_insufficient_parameters('Both registrant and admin contacts are required for .CA domain name transfer if contacts are provided') unless ($cs->has_type('registrant') && $cs->has_type('admin'));
  my @c=$cs->get('registrant');
  Net::DRI::Exception::usererr_insufficient_parameters('only one registrant is mandatory in .CA for domain_transfer_start if contacts are provided') unless (@c==1 && Net::DRI::Util::isa_contact($c[0],'Net::DRI::Data::Contact::CIRA') && length $c[0]->srid() && $c[0]->validate(1));
- push @n,['cira:registrant',$c[0]->srid()];
+ push @n,['cira:Registrant',$c[0]->srid()]; ## or <cira:registrant> ??
  @c=$cs->get('admin');
  Net::DRI::Exception::usererr_insufficient_parameters('only one admin contact is mandatory in .CA for domain_transfer_start if contacts are provided') unless (@c==1 && Net::DRI::Util::isa_contact($c[0],'Net::DRI::Data::Contact::CIRA') && length $c[0]->srid() && $c[0]->validate(1));
- push @n,['cira:contact',{type=>'admin'},$c[0]->srid()];
+ push @n,['cira:domainTransferAdmin',$c[0]->srid()]; ## or <cira:contact type="admin"> ??
  @c=$cs->get('tech');
  if (@c)
  {
   Net::DRI::Exception::usererr_insufficient_parameters('only up to 3 tech contacts are possible in .CA for domain_transfer_start') if (scalar(@c)!=scalar(grep { Net::DRI::Util::isa_contact($_,'Net::DRI::Data::Contact::CIRA') && length $_->srid() && $_->validate(1) } @c) || @c>3);
-  push @n,map { ['cira:contact',{type=>'tech'},$_->srid()] } @c;
+  push @n,map { ['cira:domainTransferTech',$_->srid()] } @c; ## or <cira:contact type="text"> ??
  }
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('cira','ciraTransfer');
- $mes->command_extension($eid,['cira:ciraChg',@n]);
- return;
+ my $eid=build_command_extension($mes,$epp,'cira:ciraTransfer');
+ $mes->command_extension($eid,\@n);
 }
 
 ####################################################################################################
@@ -135,7 +142,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2010 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
