@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .COOP EPP extensions
 ##
-## Copyright (c) 2006,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -22,7 +22,7 @@ use strict;
 use base qw/Net::DRI::Protocol::EPP/;
 use Net::DRI::Data::Contact::COOP;
 
-our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -52,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008,2009 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -65,19 +65,17 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
-sub new
+
+sub setup
 {
- my ($c,$drd,$version,$extrah,$defproduct)=@_;
- my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
-
- $e{'Net::DRI::Protocol::EPP::Extensions::COOP::Contact'}=1;
-
- my $self=$c->SUPER::new($drd,$version,[keys(%e)]);
+ my ($self,$rp)=@_;
  $self->ns({ coop => ['http://www.nic.coop/contactCoopExt-1.0','contactCoopExt-1.0.xsd'] }); ## fake XSD
  $self->capabilities('contact_update','sponsor',['add','del']);
  $self->factories('contact',sub { return Net::DRI::Data::Contact::COOP->new() });
- return $self;
+ return;
 }
 
+sub default_extensions { return qw/COOP::Contact/; }
+
 ####################################################################################################
 1;
