@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .CZ EPP extensions
 ##
-## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+## Copyright (c) 2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -22,7 +22,7 @@ use strict;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
-our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -53,7 +53,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+Copyright (c) 2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -67,18 +67,9 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub new
+sub setup
 {
- my ($c, $drd, $version, $extrah) = @_;
- my %e = map { $_ => 1 } (defined($extrah) ? (ref($extrah) ? @$extrah :
-	($extrah)) : ());
-
- $e{'Net::DRI::Protocol::EPP::Extensions::CZ::NSSET'} = 1;
- $e{'Net::DRI::Protocol::EPP::Extensions::CZ::Contact'} = 1;
- $e{'Net::DRI::Protocol::EPP::Extensions::CZ::Domain'} = 1;
- $e{'Net::DRI::Protocol::EPP::Extensions::NSgroup'} = 1;
-
- my $self = $c->SUPER::new($drd,$version,[keys(%e)]);
+ my ($self,$rp)=@_;
  $self->{defaulti18ntype}='loc'; # The registry does not provide contact postalinfo i18n type, although it is mandatory by EPP
  $self->ns({ domain  => ['http://www.nic.cz/xml/epp/domain-1.3','domain-1.3.xsd'],
              contact => ['http://www.nic.cz/xml/epp/contact-1.4','contact-1.4.xsd'],
@@ -89,10 +80,11 @@ sub new
  $self->capabilities('nsset_update','contact',['add','del']);
  $self->capabilities('nsset_update','auth',['set']);
  $self->capabilities('nsset_update','reportlevel',['set']);
- return $self;
+ return;
 }
 
 sub core_contact_types { return ('admin','tech','billing','onsite'); }
+sub default_extensions { return qw/CZ::NSSET CZ::Contact CZ::Domain NSgroup/; }
 
 ####################################################################################################
 1;
