@@ -1,6 +1,6 @@
 ## Domain Registry Interface, DNSBE EPP extensions
 ##
-## Copyright (c) 2006,2007,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2007,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -18,13 +18,14 @@
 package Net::DRI::Protocol::EPP::Extensions::DNSBE;
 
 use strict;
+use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
 use Net::DRI::Data::Contact::BE;
 use Net::DRI::Protocol::EPP::Extensions::DNSBE::Message;
 
-our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.6 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -54,7 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2007,2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2007,2008,2009 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -68,17 +69,10 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub new
+sub setup
 {
- my ($c,$drd,$version,$extrah)=@_;
- my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
-
- $e{'Net::DRI::Protocol::EPP::Extensions::DNSBE::Domain'}=1;
- $e{'Net::DRI::Protocol::EPP::Extensions::DNSBE::Contact'}=1;
- $e{'Net::DRI::Protocol::EPP::Extensions::NSgroup'}=1;
-
- my $self=$c->SUPER::new($drd,$version,[keys(%e)]);
- $version=$self->version(); ## make sure it is correctly set
+ my ($self,$rp)=@_;
+ my $version=$self->version();
  $self->ns({ dnsbe   => ['http://www.dns.be/xml/epp/dnsbe-1.0','dnsbe-1.0.xsd'],
              nsgroup => ['http://www.dns.be/xml/epp/nsgroup-1.0','nsgroup-1.0.xsd'],
           });
@@ -86,13 +80,14 @@ sub new
  $self->capabilities('domain_update','status',undef);
  $self->capabilities('domain_update','auth',undef); ## No change in authinfo (since it is not used from the beginning)
  $self->capabilities('domain_update','nsgroup',['add','del']);
- $self->factories('contact',sub { return Net::DRI::Data::Contact::BE->new()->srid('ABCD') });
+ $self->factories('contact',sub { return Net::DRI::Data::Contact::BE->new(); });
  $self->factories('message',sub { my $m=Net::DRI::Protocol::EPP::Extensions::DNSBE::Message->new(@_); $m->ns($self->{ns}); $m->version($version); return $m;});
  $self->default_parameters({domain_create => { auth => { pw => '' } } });
- return $self;
+ return;
 }
 
 sub core_contact_types { return ('admin','tech','billing','onsite'); }
+sub default_extensions { return qw/DNSBE::Domain DNSBE::Contact NSgroup/; }
 
 ####################################################################################################
 1;
