@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Message for EURid
 ##
-## Copyright (c) 2005,2006,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2006,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -18,10 +18,11 @@
 package Net::DRI::Protocol::EPP::Extensions::EURid::Message;
 
 use strict;
+use warnings;
 
 use base qw/Net::DRI::Protocol::EPP::Message/;
 
-our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -51,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006,2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2006,2008,2009 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -79,10 +80,9 @@ sub parse
  $result=$result->shift();
 
  ## We add it to the latest status extra_info seen.
- my $ra=$self->{results}->[-1]->{extra_info};
  foreach my $el ($result->getChildrenByTagNameNS($ns,'msg'))
  {
-  push @{$ra},$el->getFirstChild()->getData();
+  $self->add_to_extra_info({from => 'eurid', type => 'text', message => $el->textContent()});
  }
 }
 
