@@ -1,6 +1,6 @@
 ## Domain Registry Interface, FCCN (.PT) EPP extensions
 ##
-## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -18,11 +18,11 @@
 package Net::DRI::Protocol::EPP::Extensions::FCCN;
 
 use strict;
+use warnings;
 
-use Net::DRI::Data::Contact::FCCN;
 use base qw/Net::DRI::Protocol::EPP/;
 
-our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -52,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -65,23 +65,19 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
-sub new
+
+sub setup
 {
- my ($c,$drd,$version,$extrah)=@_;
- my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
-
- $e{'Net::DRI::Protocol::EPP::Extensions::FCCN::Contact'}=1;
- $e{'Net::DRI::Protocol::EPP::Extensions::FCCN::Domain'}=1;
-
- my $self=$c->SUPER::new($drd,$version,[keys(%e)]);
+ my ($self,$rp)=@_;
  $self->ns({ ptdomain  => ['http://www.dns.pt/xml/epp/ptdomain-1.0','ptdomain-1.0.xsd'],
              ptcontact => ['http://www.dns.pt/xml/epp/ptcontact-1.0','ptcontact-1.0.xsd'],
            });
  $self->capabilities('contact_update','status',undef);
- $self->factories('contact',sub { return Net::DRI::Data::Contact::FCCN->new(@_); });
  $self->default_parameters({domain_create => { auth => { pw => '' } } }); ## domain:authInfo is not used by FCCN
- return $self;
+ return;
 }
 
+sub default_extensions { return qw/FCCN::Contact FCCN::Domain/; }
+
 ####################################################################################################
 1;
