@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .PT Domain EPP extension commands
 ##
-## Copyright (c) 2008,2013-2014,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::FCCN::Domain;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 use Net::DRI::Util;
 use DateTime::Duration;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -49,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2013-2014,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -73,7 +77,6 @@ sub register_commands
           renew  => [ \&renew ],
           renounce => [ \&renounce ],
           delete => [ \&delete ],
-          transfer_request => [ \&transfer_request ],
          );
 
  return { 'domain' => \%tmp };
@@ -81,18 +84,27 @@ sub register_commands
 
 ####################################################################################################
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+ return $mes->command_extension_register($tag,sprintf('xmlns:ptdomain="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('ptdomain')));
+}
+
 sub create
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('Registrant contact required for .PT domain name creation') unless (Net::DRI::Util::has_contact($rd) && $rd->{contact}->has_type('registrant'));
  Net::DRI::Exception::usererr_insufficient_parameters('Tech contact required for .PT domain name creation') unless (Net::DRI::Util::has_contact($rd) && $rd->{contact}->has_type('tech'));
 
- foreach my $d (qw/legitimacy registration_basis auto_renew/)
+ foreach my $d (qw/legitimacy registration_basis add_period next_possible_registration auto_renew/)
  {
   Net::DRI::Exception::usererr_insufficient_parameters($d.' attribute is mandatory for .PT domain name creation') unless Net::DRI::Util::has_key($rd,$d);
  }
- foreach my $d (qw/auto_renew/)
+ Net::DRI::Exception::usererr_invalid_parameters('legitimacy attribute must be 0,1,2,3,4 or 5') unless ($rd->{legitimacy}=~m/^[01245]$/);
+ Net::DRI::Exception::usererr_invalid_parameters('registration_basis attribute must be 010,020,030,040,050,060,070,080,090,100') unless ($rd->{registration_basis}=~m/^(?:0[123456789]0|100)$/);
+ foreach my $d (qw/add_period next_possible_registration auto_renew/)
  {
   Net::DRI::Exception::usererr_invalid_parameters($d.' must be either 0 or 1 for .PT domain name creation') unless ($rd->{$d}==0 || $rd->{$d}==1);
  }
@@ -100,9 +112,11 @@ sub create
  my @n;
  push @n,['ptdomain:legitimacy',{type => $rd->{legitimacy}}];
  push @n,['ptdomain:registration_basis',{type => $rd->{registration_basis}}];
+ push @n,['ptdomain:addPeriod',$rd->{add_period}];
+ push @n,['ptdomain:nextPossibleRegistration',$rd->{next_possible_registration}];
  push @n,['ptdomain:autoRenew',$rd->{auto_renew}];
- $epp->message()->command_extension('ptdomain', ['create', @n]);
- return;
+ my $eid=build_command_extension($mes,$epp,'ptdomain:create');
+ $mes->command_extension($eid,\@n);
 }
 
 sub create_parse
@@ -124,7 +138,6 @@ sub create_parse
    $rinfo->{domain}->{$oname}->{roid}=$c->getFirstChild()->getData();
   }
  } continue { $c=$c->getNextSibling(); }
- return;
 }
 
 sub add_roid
@@ -136,11 +149,13 @@ sub add_roid
 sub info
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('roid attribute required for .PT domain name info') unless (Net::DRI::Util::has_key($rd,'roid'));
 
- $epp->message()->command_extension('ptdomain', ['info', add_roid($rd->{roid})]);
- return;
+ my $eid=build_command_extension($mes,$epp,'ptdomain:info');
+ my @n=add_roid($rd->{roid});
+ $mes->command_extension($eid,\@n);
 }
 
 sub info_parse
@@ -170,22 +185,24 @@ sub info_parse
    $rinfo->{domain}->{$oname}->{renew_period}=DateTime::Duration->new(years => $c->getAttribute('period'));
   }
  } continue { $c=$c->getNextSibling(); }
- return;
 }
 
 sub update
 {
  my ($epp,$domain,$toc,$rd)=@_;
+ my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('roid attribute required for .PT domain name update') unless (Net::DRI::Util::has_key($rd,'roid'));
 
- $epp->message()->command_extension('ptdomain', ['update', add_roid($rd->{roid})]);
- return;
+ my $eid=build_command_extension($mes,$epp,'ptdomain:update');
+ my @n=add_roid($rd->{roid});
+ $mes->command_extension($eid,\@n);
 }
 
 sub renew
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('roid attribute required for .PT domain name renew') unless (Net::DRI::Util::has_key($rd,'roid'));
 
@@ -198,45 +215,37 @@ sub renew
  }
  Net::DRI::Exception::usererr_invalid_parameters('only one of duration, auto_renew and not_renew attributes can be set for .PT domain name renew') if $c > 1;
 
+ my $eid=build_command_extension($mes,$epp,'ptdomain:renew');
  my @n=add_roid($rd->{roid});
  push @n,['ptdomain:autoRenew',$rd->{auto_renew}] if Net::DRI::Util::has_key($rd,'auto_renew');
  push @n,['ptdomain:notRenew',$rd->{not_renew}] if Net::DRI::Util::has_key($rd,'not_renew');
- $epp->message()->command_extension('ptdomain', ['renew', @n]);
- return;
+ $mes->command_extension($eid,\@n);
 }
 
 sub renounce
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('roid attribute required for .PT domain name renounce') unless (Net::DRI::Util::has_key($rd,'roid'));
 
- my $mes=$epp->message();
+ my $eid=build_command_extension($mes,$epp,'ptdomain:renounce');
  my @n=(['ptdomain:name',$domain]);
  push @n,add_roid($rd->{roid});
  push @n,['ptdomain:clTRID',$mes->cltrid()];
- $mes->command_extension('ptdomain', ['renounce', @n]);
- return;
+ $mes->command_extension($eid,\@n);
 }
 
-sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub delete
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('roid attribute required for .PT domain name delete') unless (Net::DRI::Util::has_key($rd,'roid'));
 
- $epp->message()->command_extension('ptdomain', ['delete', add_roid($rd->{roid})]);
- return;
-}
-
-sub transfer_request
-{
- my ($epp,$domain,$rd)=@_;
-
- Net::DRI::Exception::usererr_insufficient_parameters('you have to specify authinfo for .PT domain transfer (mapped to transferKey)') unless Net::DRI::Util::has_auth($rd);
-
- $epp->message()->command_extension('ptdomain',  ['transfer', ['transferKey',$rd->{"auth"}->{"pw"}]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'ptdomain:delete');
+ my @n=add_roid($rd->{roid});
+ $mes->command_extension($eid,\@n);
 }
 
 ####################################################################################################
