@@ -1,7 +1,6 @@
 ## Domain Registry Interface, .CO.CZ EPP extensions
 ##
 ## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-## Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -12,6 +11,9 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::IRegistry;
@@ -21,6 +23,8 @@ use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -51,7 +55,6 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -69,8 +72,8 @@ sub setup
 {
  my ($self,$rp)=@_;
  $self->{defaulti18ntype}='loc'; # The registry does not provide contact postalinfo i18n type, although it is mandatory by EPP
- $self->ns({ domain  => 'http://www.nic.cz/xml/epp/domain-1.4',
-             contact => 'http://www.nic.cz/xml/epp/contact-1.5',
+ $self->ns({ domain  => ['http://www.nic.cz/xml/epp/domain-1.4','domain-1.4.xsd'],
+             contact => ['http://www.nic.cz/xml/epp/contact-1.5','contact-1.5.xsd'],
           });
  $self->capabilities('domain_update','status',undef);
  $self->capabilities('domain_update','nsset',['set']);
