@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .IT EPP extensions
 ##
-## Copyright (c) 2009-2010,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2009-2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,6 +10,9 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::IT;
@@ -21,6 +24,8 @@ use base qw/Net::DRI::Protocol::EPP/;
 
 use Net::DRI::Data::Contact::IT;
 
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -49,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2009-2010,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2009-2010 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -68,9 +73,9 @@ sub setup
  my ($self,$rp)=@_;
 
  $self->ns({
-               'it_epp' => 'http://www.nic.it/ITNIC-EPP/extepp-1.0',
-               'extcon' => 'http://www.nic.it/ITNIC-EPP/extcon-1.0',
-               'extdom' => 'http://www.nic.it/ITNIC-EPP/extdom-1.0',
+               'it_epp'        => [ 'http://www.nic.it/ITNIC-EPP/extepp-1.0', 'extepp-1.0.xsd' ],
+               'it_contact'    => [ 'http://www.nic.it/ITNIC-EPP/extcon-1.0', 'extcon-1.0.xsd' ],
+               'it_domain'     => [ 'http://www.nic.it/ITNIC-EPP/extdom-1.0', 'extdom-1.0.xsd' ],
        });
 
  $self->factories('contact', sub { return Net::DRI::Data::Contact::IT->new(); });
