@@ -1,16 +1,20 @@
 ## Domain Registry Interface, .IT Contact EPP extension
 ##
-## Copyright (C) 2009-2010,2013,2016 Tower Technologies. All rights reserved.
-##           (c) 2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (C) 2009-2010 Tower Technologies. All rights reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License v2.
+#
+# 
+#
 
 package Net::DRI::Protocol::EPP::Extensions::IT::Contact;
 
 use strict;
 use warnings;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -31,8 +35,7 @@ Alessandro Zummo, E<lt>a.zummo@towertech.itE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2009-2010,2013,2016 Tower Technologies.
-Copyright (c) 2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (C) 2009-2010 Tower Technologies.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -55,9 +58,20 @@ sub register_commands
        return { 'contact' => $ops };
 }
 
+sub build_command_extension
+{
+       my ($msg, $epp, $tag) = @_;
+
+       return $msg->command_extension_register($tag,
+               sprintf('xmlns:extcon="%s" xsi:schemaLocation="%s %s"', $msg->nsattrs('it_contact')));
+}
+
 sub fix_contact
 {
        my ($epp, $c, $op) = @_;
+       my $msg = $epp->message;
+
+       my $eid = build_command_extension($msg, $epp, 'extcon:' . $op);
 
        my @ext;
 
@@ -81,11 +95,8 @@ sub fix_contact
        push @ext, [ 'extcon:registrant', @registrant ]
                if scalar @registrant;
 
-       if (@ext)
-       {
-       	       $epp->message()->command_extension('extcon', [$op, @ext]);
-       }
-       return;
+       $msg->command_extension($eid, [ @ext ])
+               if scalar @ext;
 }
 
 sub create
