@@ -21,7 +21,7 @@ package Net::DRI::Protocol::EPP::Extensions::NO::Result;
 
 use strict;
 
-our $VERSION = do { my @r = ( q$Revision: 1.2 $ =~ /\d+/gxm ); sprintf( "%d" . ".%02d" x $#r, @r ); };
+our $VERSION = do { my @r = ( q$Revision: 1.3 $ =~ /\d+/gxm ); sprintf( "%d" . ".%02d" x $#r, @r ); };
 
 =pod
 
@@ -98,16 +98,15 @@ sub condition_parse {
     my ( $po, $otype, $oaction, $oname, $rinfo ) = @_;
     my $mes = $po->message();
 
-    my $condata = $mes->get_extension('no_result','conditions');
+    my $condata = $mes->get_extension( 'no_result', 'conditions' );
     return unless $condata;
 
-    parse($mes,$otype,$oname,$rinfo,$condata);
+    parse( $mes, $otype, $oname, $rinfo, $condata );
+    return 1;
 }
 
-
-sub parse
-{
-    my ($mes,$otype,$oname,$rinfo,$node)=@_;
+sub parse {
+    my ( $mes, $otype, $oname, $rinfo, $node ) = @_;
     my $NS = $mes->ns('no_result');
     my @conditions;
 
