@@ -1,7 +1,6 @@
 ## Domain Registry Interface, Neulevel EPP IDN Language
 ##
-## Copyright (c) 2009,2013 Jouanne Mickael <grigouze@gandi.net>. All rights reserved.
-## Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2009 Jouanne Mickael <grigouze@gandi.net>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,17 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::NeuLevel::IDNLanguage;
 
 use strict;
-use warnings;
-use feature 'state';
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -50,8 +52,7 @@ Jouanne Mickael E<lt>grigouze@gandi.netE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2009,2013 Jouanne Mickael <grigouze@gandi.net>.
-Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2009 Jouanne Mickael <grigouze@gandi.net>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -68,29 +69,31 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- state $commands = { 'domain' => { 'create' => [ \&create, undef ] } };
- return $commands;
-}
+ my %tmp=(
+           create => [ \&create, undef ],
+         );
 
-sub setup
-{
- my ($class,$po,$version)=@_;
- $po->ns({ 'neulevel' => 'urn:ietf:params:xml:ns:neulevel-1.0' });
- return;
+ return { 'domain' => \%tmp };
 }
 
 ####################################################################################################
 
+sub add_language
+{
+ my ($tag,$epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
+
+ if (Net::DRI::Util::has_key($rd,'language'))
+ {
+  Net::DRI::Exception::usererr_invalid_parameters('IDN language tag must be of type XML schema language') unless Net::DRI::Util::xml_is_language($rd->{language});
+  my $eid=$mes->command_extension_register($tag,'xmlns:neulevel="urn:ietf:params:xml:ns:neulevel-1.0" xsi:schemaLocation="urn:ietf:params:xml:ns:neulevel-1.0 neulevel-1.0.xsd"');
+  $mes->command_extension($eid,['neulevel:unspec', 'IDNLang=' . $rd->{language}]);
+ }
+}
+
 sub create
 {
- my ($epp, $domain, $rd)=@_;
-
- return unless Net::DRI::Util::has_key($rd,'language');
-
- Net::DRI::Exception::usererr_invalid_parameters('IDN language tag must be of type XML schema language') unless Net::DRI::Util::xml_is_language($rd->{language});
- $epp->message()->command_extension('neulevel', ['extension', ['neulevel:unspec', 'IDNLang=' . $rd->{language}]]);
-
- return;
+ return add_language('idn:create',@_);
 }
 
 ####################################################################################################
