@@ -1,9 +1,8 @@
 ## Domain Registry Interface, EPP Extension for .travel UIN
 ## (ICANN Sponsored TLD Registry Agreement, Part IV)
 ##
-## Copyright (c) 2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 ##                    All rights reserved.
-## Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -13,16 +12,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::NeuLevel::UIN;
 
 use strict;
-use warnings;
-use feature 'state';
 
 use Net::DRI::Util;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -51,8 +53,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -70,20 +71,13 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class, $version) = @_;
- state $domain = {
-                  create           => [ \&add_uin, undef ],
-                  transfer_request => [ \&add_uin, undef ],
-                  renew            => [ \&renew,   undef ],
-                 };
- state $commands = { domain => $domain };
- return $commands;
-}
+ my %tmp = (
+           create => [ \&add_uin, undef ],
+           transfer_request => [ \&add_uin, undef ],
+           renew => [ \&renew, undef ],
+         );
 
-sub setup
-{
- my ($class,$po,$version)=@_;
- $po->ns({ 'neulevel' => 'urn:ietf:params:xml:ns:neulevel-1.0' });
- return;
+ return { 'domain' => \%tmp };
 }
 
 ####################################################################################################
@@ -93,16 +87,19 @@ sub setup
 sub add_uin
 {
  my ($epp, $domain, $rd) = @_;
+ my $mes = $epp->message();
 
  return unless Net::DRI::Util::has_key($rd,'uin');
 
- $epp->message()->command_extension('neulevel', ['extension', ['unspec', 'UIN=' . $rd->{uin}]]);
- return;
+ my $eid = $mes->command_extension_register('neulevel:extension',
+	'xmlns:neulevel="urn:ietf:params:xml:ns:neulevel-1.0" xsi:schemaLocation="urn:ietf:params:xml:ns:neulevel-1.0 neulevel-1.0.xsd"');
+ $mes->command_extension($eid, ['neulevel:unspec', 'UIN=' . $rd->{uin}]);
 }
 
 sub renew
 {
  my ($epp, $domain, $rd) = @_;
+ my $mes = $epp->message();
  my @vals = qw(RestoreReasonCode RestoreComment TrueData ValidUse UIN);
  my %info;
  my $comment;
@@ -122,8 +119,9 @@ sub renew
   $info{UIN} = $rd->{uin};
  }
 
- $epp->message()->command_extension('neulevel', ['extension', ['unspec', join(' ', map { $_ . '=' . $info{$_} } grep { defined($info{$_}) } @vals)]]);
- return;
+ my $eid = $mes->command_extension_register('neulevel:extension',
+	'xmlns:neulevel="urn:ietf:params:xml:ns:neulevel-1.0" xsi:schemaLocation="urn:ietf:params:xml:ns:neulevel-1.0 neulevel-1.0.xsd"');
+ $mes->command_extension($eid, ['neulevel:unspec', join(' ', map { $_ . '=' . $info{$_} } grep { defined($info{$_}) } @vals)]);
 }
 
 ####################################################################################################
