@@ -1,7 +1,6 @@
 ## Domain Registry Interface, .JOBS contact extension
 ##
-## Copyright (c) 2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-## Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
+## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -12,16 +11,18 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::VeriSign::JobsContact;
 
 use strict;
-use warnings;
-use feature 'state';
-
 use Net::DRI::Util;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -51,8 +52,7 @@ Tonnerre Lombard E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -69,22 +69,16 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- state $cmds = { 'contact' => { 'create' => [ \&create, undef ],
-                                'update' => [ \&update, undef ],
-                                'info'   => [ undef, \&info_parse ],
-                              }
-               };
+ my %contacttmp=(
+	   create =>		[ \&create, undef ],
+	   update =>		[ \&update, undef ],
+	   info =>		[ undef, \&info_parse ]
+	 );
 
- return $cmds;
+ return { 'contact' => \%contacttmp };
 }
 
-sub setup
-{
- my ($class,$po,$version)=@_;
- state $rns = { 'jobsContact' => 'http://www.verisign.com/epp/jobsContact-1.0' };
- $po->ns($rns);
- return;
-}
+our @NS=('http://www.verisign.com/epp/jobsContact-1.0','http://www.verisign.com/epp/jobsContact-1.0 jobsContact-1.0.xsd');
 
 ####################################################################################################
 
@@ -93,6 +87,7 @@ sub setup
 sub add_job
 {
 	my ($cmd, $epp, $contact, $rd) = @_;
+	my $mes = $epp->message();
 	my $info;
 	my @jobdata;
 
@@ -114,51 +109,47 @@ sub add_job
 
 	return unless (@jobdata);
 
-	$epp->message()->command_extension('jobsContact', [$cmd, @jobdata]);
-	return;
+	my $eid = $mes->command_extension_register('jobsContact:' . $cmd,sprintf('xmlns:jobsContact="%s" xsi:schemaLocation="%s"',@NS));
+	$mes->command_extension($eid, \@jobdata);
 }
 
 sub create
 {
-	my (@args)=@_;
-	return add_job('create', @args);
+	return add_job('create', @_);
 }
 
 sub update
 {
-	my (@args)=@_;
-	return add_job('update', @args);
+	return add_job('update', @_);
 }
 
 sub info_parse
 {
 	my ($po,$otype,$oaction,$oname,$rinfo)=@_;
 	my $mes = $po->message();
-	my $infdata = $mes->get_extension('jobsContact', 'infData');
+	my $infdata = $mes->get_extension($NS[0],'infData');
         return unless (defined($infdata));
 
 	my $jobinfo = {};
 	my $c;
-	my $ns = $mes->ns('jobsContact');
 
-	$c = $infdata->getChildrenByTagNameNS($ns, 'title');
+	$c = $infdata->getChildrenByTagNameNS($NS[0], 'title');
 	$jobinfo->{title} = $c->shift()->getFirstChild()->getData() if ($c);
 
-	$c = $infdata->getChildrenByTagNameNS($ns, 'website');
+	$c = $infdata->getChildrenByTagNameNS($NS[0], 'website');
 	$jobinfo->{website} = $c->shift()->getFirstChild()->getData() if ($c);
 
-	$c = $infdata->getChildrenByTagNameNS($ns, 'industryType');
+	$c = $infdata->getChildrenByTagNameNS($NS[0], 'industryType');
 	$jobinfo->{industry} = $c->shift()->getFirstChild()->getData() if ($c);
 
-	$c = $infdata->getChildrenByTagNameNS($ns, 'isAdminContact');
+	$c = $infdata->getChildrenByTagNameNS($NS[0], 'isAdminContact');
 	$jobinfo->{admin} = (lc($c->shift()->getFirstChild()->getData()) eq 'yes')? 1 : 0 if ($c);
 
-	$c = $infdata->getChildrenByTagNameNS($ns, 'isAssociationMember');
+	$c = $infdata->getChildrenByTagNameNS($NS[0], 'isAssociationMember');
 	$jobinfo->{member} = (lc($c->shift()->getFirstChild()->getData()) eq 'yes')? 1 : 0 if ($c);
 
         my $contact = $rinfo->{$otype}->{$oname}->{self};
 	$contact->jobinfo($jobinfo);
-	return;
 }
 
 ####################################################################################################
