@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Gandi Web Services Connection handling
 ##
-## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -20,7 +20,7 @@ package Net::DRI::Protocol::Gandi::WS::Connection;
 use strict;
 use XMLRPC::Lite; ## needed to have XMLRPC::Data
 
-our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,8 +66,7 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub login
 {
- shift if ($_[0] eq __PACKAGE__);
- my ($cm,$id,$pass,$cltrid)=@_;
+ my ($class,$cm,$id,$pass,$cltrid)=@_;
  my $mes=$cm->();
  $mes->method('login');
  $mes->params([$id,$pass,XMLRPC::Data->type('boolean')->value(0)]);
@@ -76,18 +75,22 @@ sub login
 
 sub parse_login
 {
- shift if ($_[0] eq __PACKAGE__);
- my $mes=shift;
+ my ($class,$mes)=@_;
  $mes->errmsg($mes->is_success()? 'Login OK' : 'Login failed') unless $mes->errmsg();
  return $mes->result_status();
 }
 
 sub extract_session
 {
- shift if ($_[0] eq __PACKAGE__);
- my $mes=shift;
+ my ($class,$mes)=@_;
  return { id => $mes->value() };
 }
 
+sub transport_default
+{
+ my ($self,$tname)=@_;
+ return (defer => 1, has_login => 1, has_logout => 0);
+}
+
 ####################################################################################################
 1;
