@@ -1,6 +1,6 @@
 ## Domain Registry Interface, IRIS XCP Connection handling
 ##
-## Copyright (c) 2008-2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,13 +10,14 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::IRIS::XCP;
 
-use utf8;
 use strict;
-use warnings;
 
 use XML::LibXML ();
 
@@ -26,6 +27,8 @@ use Net::DRI::Data::Raw;
 use Net::DRI::Protocol::ResultStatus;
 use Net::DRI::Protocol::IRIS::Core;
 
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -54,7 +57,7 @@ Only SASL PLAIN is handled
 
 =item *
 
-Blocks split over multiple chunks are not handled, except for application data
+Blocks splitted over multiple chunks are not handled, except for application data
 
 =item *
 
@@ -85,7 +88,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -99,14 +102,14 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub parse_greeting ## §4.2
+sub parse_greeting ## 4.2
 {
  my $dr=shift;
  ## TODO: really parse something ?
  return Net::DRI::Protocol::ResultStatus->new_success('COMMAND_SUCCESSFUL','Greeting OK','en');
 }
 
-sub read_data # §4
+sub read_data # 4
 {
  my ($class,$to,$sock)=@_;
 
@@ -117,7 +120,7 @@ sub read_data # §4
  my $keepopen=parse_block_header($hdr);
  $to->send_logout() unless ($keepopen); ## will not truly send anything, as there is no logout, but will properly close the socket and prepare everything as needed for next connection
 
- ## We do not handle blocks split over multiple chunks, except for application data
+ ## We do not handle blocks splitted over multiple chunks, except for application data
  my $m='';
  my ($lastchunk,$datacomplete,$chunktype);
  while(($lastchunk,$datacomplete,$chunktype,$data)=parse_chunk($sock))
@@ -130,7 +133,7 @@ sub read_data # §4
    die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_SYNTAX_ERROR','Extra SASL data returned by server, currently not handled','en'));
   } elsif ($chunktype==4+0+1) ## as=authentication success
   {
-   ## We do not parse anything. If so needed, see §6 of RFC4991, and Core::parse_authentication
+   ## We do not parse anything. If so needed, see 6 of RFC4991, and Core::parse_authentication
    next;
   } elsif ($chunktype==4+2+0) ## af=authentication failure
   {
@@ -147,14 +150,14 @@ sub read_data # §4
 
   last if $lastchunk==1;
  }
- die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_FAILED','Last chunk does not have DC=1','en')) unless $datacomplete==1; ## TODO: does that happen IRL ?
+ die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_FAILED','Last chunk has not DC=1','en')) unless $datacomplete==1; ## TODO: does that happen IRL ?
  $m=Net::DRI::Util::decode_utf8($m); ## do it only once at end, when all chunks of application data were joined together again
 
  die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_SYNTAX_ERROR',$m? 'Got unexpected reply message: '.$m : '<empty message from server>','en')) unless ($m=~m!</(?:\S+:)?response>\s*$!s); ## we do not handle other things than plain responses (see Message)
  return Net::DRI::Data::Raw->new_from_xmlstring($m);
 }
 
-sub write_message ## §5
+sub write_message ## 5
 {
  my ($self,$to,$msg)=@_;
 
@@ -173,7 +176,7 @@ sub keepalive
 
 ####################################################################################################
 
-sub parse_block_header ## §5
+sub parse_block_header ## 5
 {
  my $d=shift; ## one-octet
  die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_FAILED_CLOSING','Unable to read 1 byte block header','en')) unless $d;
@@ -186,7 +189,7 @@ sub parse_block_header ## §5
  return $keepopen;
 }
 
-sub parse_chunk_header ## §6
+sub parse_chunk_header ## 6
 {
  my $d=shift; ## one-octet
  die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_FAILED_CLOSING','Unable to read 1 byte chunk header','en')) unless $d;
@@ -201,7 +204,7 @@ sub parse_chunk_header ## §6
  return ($lc,$dc,$ct);
 }
 
-sub parse_chunk ## §6
+sub parse_chunk ## 6
 {
  my $sock=shift;
  my $data;
