@@ -1,7 +1,7 @@
 ## Domain Registry Interface, OVH Web Services Protocol
 ## As seen on http://www.ovh.com/soapi/fr/ and http://www.verot.org/ovhapi/ and http://wikikillers.eu/
 ##
-## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -14,16 +14,17 @@
 #
 # 
 #
-#########################################################################################
+####################################################################################################
 
 package Net::DRI::Protocol::OVH::WS;
 
 use strict;
+use warnings;
 
 use base qw(Net::DRI::Protocol);
 use Net::DRI::Protocol::OVH::WS::Message;
 
-our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -53,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -69,31 +70,27 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my $c=shift;
- my ($drd,$version,$extrah)=@_;
-
- my $self=$c->SUPER::new(); ## we are now officially a Net::DRI::Protocol object
+ my ($c,$drd,$rp)=@_;
+ my $self=$c->SUPER::new();
  $self->name('ovh_ws');
- $self->version($VERSION);
-
- $self->capabilities({});
-
- $self->factories({ message => sub { my $m=Net::DRI::Protocol::OVH::WS::Message->new(); $m->version($VERSION); return $m; },
-                  });
-
- bless($self,$c); ## rebless
-
- $self->_load($extrah);
+ $self->version('1.4.1');
+ $self->factories('message',sub { my $m=Net::DRI::Protocol::OVH::WS::Message->new(); $m->version('1.4.1'); return $m; });
+ $self->_load($rp);
  return $self;
 }
 
 sub _load
 {
- my ($self,$extrah)=@_;
+ my ($self,$rp)=@_;
  my @class=map { 'Net::DRI::Protocol::OVH::WS::'.$_ } (qw/Account Domain/);
  $self->SUPER::_load(@class);
 }
 
+sub transport_default
+{
+ my ($self)=@_;
+ return (protocol_connection => 'Net::DRI::Protocol::OVH::WS::Connection', protocol_version => '1.4.1');
+}
 
 ####################################################################################################
 1;
