@@ -1,6 +1,6 @@
 ## Domain Registry Interface, RRP Host commands
 ##
-## Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2006,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -20,8 +20,9 @@ package Net::DRI::Protocol::RRP::Core::Host;
 use strict;
 use Net::DRI::Protocol::RRP;
 use Net::DRI::Data::Hosts;
+use Net::DRI::Util;
 
-our $VERSION=do { my @r=(q$Revision: 1.9 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.10 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -51,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2006,2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,7 +64,6 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
-
 #########################################################################################
 
 sub register_commands
@@ -158,7 +158,7 @@ sub mod
  my ($rrp,$hostname,$todo)=@_;
  my $mes=$rrp->message();
 
- Net::DRI::Exception::usererr_invalid_parameters($todo." must be a Net::DRI::Data::Changes object") unless ($todo && UNIVERSAL::isa($todo,'Net::DRI::Data::Changes'));
+ Net::DRI::Exception::usererr_invalid_parameters($todo.' must be a Net::DRI::Data::Changes object') unless Net::DRI::Util::isa_changes($todo);
  if ((grep { ! /^(?:ip|name)$/ } $todo->types()) ||
      (grep { ! /^(?:add|del)$/ } $todo->types('ip')) ||
      (grep { ! /^(?:set)$/ } $todo->types('name'))
