@@ -1,6 +1,6 @@
 ## Domain Registry Interface, SOAP Transport
 ##
-## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008-2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -13,19 +13,21 @@
 #
 # 
 #
-#########################################################################################
+####################################################################################################
 
 package Net::DRI::Transport::HTTP::SOAPLite;
 
-use base qw(Net::DRI::Transport);
 use strict;
+use warnings;
+
+use base qw(Net::DRI::Transport);
 
 use Net::DRI::Exception;
 use Net::DRI::Data::Raw;
 use Net::DRI::Util;
 use SOAP::Lite;
 
-our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -55,7 +57,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008-2010 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -68,19 +70,29 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
+
 sub new
 {
- my $class=shift;
- my $drd=shift;
- my $po=shift;
- my %opts=(@_==1 && ref($_[0]))? %{$_[0]} : @_;
- my $self=$class->SUPER::new(\%opts); ## We are now officially a Net::DRI::Transport instance
+ my ($class,$ctx,$rp)=@_;
+ my %opts=%$rp;
+ my $po=$ctx->{protocol};
+
+ my %t=(message_factory => $po->factories()->{message});
+ if (exists($opts{protocol_connection}) && $opts{protocol_connection})
+ {
+  $t{protocol_connection}=$opts{protocol_connection};
+  $t{protocol_connection}->require or Net::DRI::Exception::err_failed_load_module('transport/socket',$t{protocol_connection},$@);
+  if ($t{protocol_connection}->can('transport_default'))
+  {
+   %opts=($t{protocol_connection}->transport_default('soaplite'),%opts);
+  }
+ }
+
+ my $self=$class->SUPER::new($ctx,\%opts); ## We are now officially a Net::DRI::Transport instance
  $self->is_sync(1);
  $self->name('soaplite');
  $self->version($VERSION);
 
- my %t=(message_factory => $po->factories()->{message});
- $t{trid_factory}=(exists($opts{trid}) && (ref($opts{trid}) eq 'CODE'))? $opts{trid} : \&Net::DRI::Util::create_trid_1;
  $t{has_login}=(exists($opts{has_login}) && defined($opts{has_login}))? $opts{has_login} : 0;
  $t{has_logout}=(exists($opts{has_logout}) && defined($opts{has_logout}))? $opts{has_logout} : 0;
  $self->has_state($t{has_login});
@@ -91,13 +103,7 @@ sub new
   $t{$p}=$opts{$p};
  }
 
- if ($t{has_login})
- {
-  $t{session_data}={};
- } else
- {
-  $t{session_data}={ id => $t{client_login}, pass => $t{client_password} };
- }
+ $t{session_data}=$t{has_login}? {} : { id => $t{client_login}, pass => $t{client_password} };
 
  foreach my $p (qw/uri proxy_uri/)
  {
@@ -110,7 +116,6 @@ sub new
  if ($t{has_login} || $t{has_logout})
  {
   Net::DRI::Exception::usererr_insufficient_parameters('protocol_connection must be provided') unless (defined($pc));
-  $pc->require or Net::DRI::Exception::err_failed_load_module('transport/socket',$pc,$@);
  }
  if ($t{has_login})
  {
@@ -137,7 +142,7 @@ sub new
    $self->current_state(0);
   } else ## we will open NOW 
   {
-   $self->open_connection();
+   $self->open_connection($ctx);
   }
  } else
  {
@@ -151,24 +156,18 @@ sub new
 sub soap { my ($self,$v)=@_; $self->{transport}->{soap}=$v if @_==2; return $self->{transport}->{soap}; }
 sub session_data { my ($self,$v)=@_; $self->{transport}->{session_data}=$v if @_==2; return $self->{transport}->{session_data}; }
 
-sub soap_fault
-{
- my($soap,$res)=@_; 
- my $msg=ref($res)? $res->faultstring() : $soap->transport()->status();
- Net::DRI::Exception->die(1,'transport/http/soaplite',7,'SOAP fault: '.$msg);
-}
-
 sub init
 {
  my ($self)=@_;
  return if defined($self->soap());
- my $soap=SOAP::Lite->new()->on_fault(\&soap_fault)->uri($self->{transport}->{uri})->proxy($self->{transport}->{proxy_uri});
+ my $soap=SOAP::Lite->new()->uri($self->{transport}->{uri})->proxy($self->{transport}->{proxy_uri});
+ $soap->transport()->agent(sprintf('Net::DRI/%s Net::DRI::Transport::HTTP::SOAPLite/%s ',$Net::DRI::VERSION,$VERSION).$soap->transport()->agent());
  $self->soap($soap);
 }
 
 sub send_login
 {
- my ($self)=@_;
+ my ($self,$ctx)=@_;
  my $t=$self->{transport};
  return unless $t->{has_login};
  foreach my $p (qw/client_login client_password/)
@@ -177,13 +176,9 @@ sub send_login
  }
 
  my $pc=$t->{protocol_connection};
- my $cltrid=$t->{trid_factory}->($self->name());
+ my $cltrid=$self->generate_trid($self->{logging_ctx}->{registry});
  my $login=$pc->login($t->{message_factory},$t->{client_login},$t->{client_password},$cltrid);
- my $lm=$login->method();
- my $res=$self->soap()->$lm(@{$login->params()});
- ## $self->logging($cltrid,1,0,1,$login);
- Net::DRI::Exception->die(1,'transport/soapwsdl',4,'Unable to send login message due to SOAP fault: '.$res->faultcode().' '.$res->faultstring()) if ($res->fault());
- ## $self->logging($cltrid,1,1,1,$dr);
+ my $res=$self->_send_receive({otype=>'session',oaction=>'login',trid=>$cltrid,phase=>'opening'},$login);
  my $msg=$t->{message_factory}->();
  $msg->parse(Net::DRI::Data::Raw->new(1,[$res->result()]));
  my $rc=$pc->parse_login($msg);
@@ -199,13 +194,9 @@ sub send_logout
  return unless $t->{has_logout};
 
  my $pc=$t->{protocol_connection};
- my $cltrid=$t->{trid_factory}->($self->name());
+ my $cltrid=$self->generate_trid($self->{logging_ctx}->{registry});
  my $logout=$pc->logout($t->{message_factory},$cltrid,$t->{session_data});
- my $lm=$logout->method();
- my $res=$self->soap()->$lm(@{$logout->params()});
- ## $self->logging($cltrid,3,0,1,$logout);
- Net::DRI::Exception->die(1,'transport/soapwsdl',4,'Unable to send logout message due to SOAP fault: '.$res->faultcode().' '.$res->faultstring()) if ($res->fault());
- ## $self->logging($cltrid,3,1,1,$dr);
+ my $res=$self->_send_receive({otype=>'session',oaction=>'logout',trid=>$cltrid,phase=>'closing'},$logout);
  my $msg=$t->{message_factory}->();
  $msg->parse(Net::DRI::Data::Raw->new(1,[$res->result()]));
  my $rc=$pc->parse_logout($msg);
@@ -214,11 +205,32 @@ sub send_logout
  $self->session_data({});
 }
 
+sub _send_receive
+{
+ my ($self,$ctx,$msg)=@_;
+ my $soap=$self->soap();
+ my $err;
+ my $res=$soap->on_fault(sub { (undef,$err)=@_; return; })->call($msg->method(),@{$msg->params()});
+ if (my $httpres=$soap->transport()->http_response())
+ {
+  $self->log_output('notice','transport',$ctx,{direction=>'out',message=>$httpres->request()});
+  $self->log_output('notice','transport',$ctx,{direction=>'in', message=>$httpres});
+ } else
+ {
+  $self->log_output('error','transport',$ctx,{direction=>'out',message=>'No response for message '.$soap->serializer()->envelope(method => $msg->method(), @{$msg->params()})});
+ }
+ return $res if defined $res && ref $res && ! $res->fault() && ! defined $err;
+
+ Net::DRI::Exception->die(1,'transport/soaplite',4,'Unable to send message due to SOAP fault: '.$err->faultcode().' '.$err->faultstring()) if defined $err && ref $err;
+ Net::DRI::Exception->die(1,'transport/soaplite',4,'Unable to send message due to SOAP transport error: '.$soap->transport()->status()) unless $soap->transport()->is_success();
+ Net::DRI::Exception->die(1,'transport/soaplite',4,'Unable to send message due to SOAP deserialization error: '.$err);
+}
+
 sub open_connection
 {
- my ($self)=@_;
+ my ($self,$ctx)=@_;
  $self->init();
- $self->send_login();
+ $self->send_login($ctx);
  $self->current_state(1);
  $self->time_open(time());
  $self->time_used(time());
@@ -234,7 +246,7 @@ sub close_connection
 
 sub end
 {
- my $self=shift;
+ my ($self)=@_;
  if ($self->has_state() && $self->current_state())
  {
   eval
@@ -251,25 +263,24 @@ sub end
 
 sub send
 {
- my ($self,$trid,$tosend)=@_;
- $self->SUPER::send($trid,$tosend,\&_soap_send,sub {});
+ my ($self,$ctx,$tosend)=@_;
+ $self->SUPER::send($ctx,$tosend,\&_soap_send,sub {});
 }
 
 sub _soap_send
 {
- my ($self,$count,$tosend)=@_;
+ my ($self,$count,$tosend,$ctx)=@_;
  my $t=$self->{transport};
  $tosend->add_session($self->session_data());
- my $m=$tosend->method();
- my $res=$self->soap()->$m(@{$tosend->params()});
+ my $res=$self->_send_receive($ctx,$tosend);
  $t->{last_reply}=$res;
  return 1; ## very important
 }
 
 sub receive
 {
- my ($self,$trid)=@_;
- return $self->SUPER::receive($trid,\&_soap_receive);
+ my ($self,$ctx,$count)=@_;
+ return $self->SUPER::receive($ctx,\&_soap_receive);
 }
 
 sub _soap_receive
@@ -277,9 +288,8 @@ sub _soap_receive
  my ($self,$count)=@_;
  my $t=$self->{transport};
  my $r=$t->{last_reply};
- Net::DRI::Exception->die(1,'transport/soapwsdl',7,'SOAP fault: '.$r->faultcode().' '.$r->faultstring()) if ($r->fault());
  $t->{last_reply}=undef;
- return Net::DRI::Data::Raw->new(1,[$r->result()]);
+ return Net::DRI::Data::Raw->new(6,[$r->result()]);
 }
 
 ####################################################################################################
